<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>FileLabelBox</name>
    <message>
        <location filename="../../src/control/file-label-box.cpp" line="57"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../../src/control/file-label-box.cpp" line="62"/>
        <source>Edit Color</source>
        <translation>编辑颜色</translation>
    </message>
    <message>
        <location filename="../../src/control/file-label-box.cpp" line="70"/>
        <source>Delete</source>
        <translation>删除标记</translation>
    </message>
    <message>
        <location filename="../../src/control/file-label-box.cpp" line="75"/>
        <source>Create New Label</source>
        <translation>创建标记</translation>
    </message>
</context>
<context>
    <name>HeaderBar</name>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="82"/>
        <source>Create Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="96"/>
        <source>Open Terminal</source>
        <translation>打开终端</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="110"/>
        <source>Go Back</source>
        <translation>后退</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="118"/>
        <source>Go Forward</source>
        <translation>前进</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="158"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="168"/>
        <source>View Type</source>
        <translation>视图类型</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="195"/>
        <source>Sort Type</source>
        <translation>排序类型</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="221"/>
        <source>Option</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="265"/>
        <source>Operate Tips</source>
        <translation>操作提示</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="266"/>
        <source>Don&apos;t find any terminal, please install at least one terminal!</source>
        <translation>没有找到任何终端插件，请确认您至少安装了一个！</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation type="vanished">最小化</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">关闭</translation>
    </message>
</context>
<context>
    <name>HeaderBarContainer</name>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="563"/>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="575"/>
        <source>Maximize/Restore</source>
        <translation>最大化/还原</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">还原</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation type="vanished">最大化</translation>
    </message>
    <message>
        <location filename="../../src/control/header-bar.cpp" line="596"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="108"/>
        <location filename="../../src/windows/main-window.cpp" line="611"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="295"/>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="302"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="vanished">删除文件警告</translation>
    </message>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="1265"/>
        <source>Delete Permanently</source>
        <translation>永久删除</translation>
    </message>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="1266"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>您确定要删除这些文件吗？一旦开始删除，这些文件将不可再恢复。</translation>
    </message>
    <message>
        <source>Peony Qt</source>
        <translation type="vanished">文件管理器</translation>
    </message>
    <message>
        <location filename="../../src/windows/main-window.cpp" line="624"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
</context>
<context>
    <name>NavigationSideBar</name>
    <message>
        <source>All tags...</source>
        <translation type="vanished">所有标记...</translation>
    </message>
</context>
<context>
    <name>NavigationSideBarContainer</name>
    <message>
        <location filename="../../src/control/navigation-side-bar.cpp" line="273"/>
        <source>All tags...</source>
        <translation>所有标记...</translation>
    </message>
</context>
<context>
    <name>NavigationTabBar</name>
    <message>
        <location filename="../../src/control/navigation-tab-bar.cpp" line="118"/>
        <source>Search &quot;%1&quot; in &quot;%2&quot;</source>
        <translation>在%2中搜索%1</translation>
    </message>
</context>
<context>
    <name>OperationMenu</name>
    <message>
        <source>Advance Search</source>
        <translation type="vanished">高级搜索</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="66"/>
        <source>Keep Allow</source>
        <translation>置顶窗口</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="82"/>
        <source>Show Hidden</source>
        <translation>显示隐藏文件</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="89"/>
        <source>Forbid thumbnailing</source>
        <translation>禁用缩略图</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="98"/>
        <source>Resident in Backend</source>
        <translation>常驻后台</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="107"/>
        <source>Parallel Operations</source>
        <translation>允许操作并行</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="115"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="119"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
<context>
    <name>OperationMenuEditWidget</name>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="148"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="159"/>
        <source>copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="168"/>
        <source>paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="177"/>
        <source>cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../../src/control/operation-menu.cpp" line="186"/>
        <source>trash</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>PeonyApplication</name>
    <message>
        <source>Peony-Qt</source>
        <translation type="vanished">文件管理器</translation>
    </message>
    <message>
        <source>peony-qt</source>
        <translation type="vanished">文件管理器</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="140"/>
        <source>Files or directories to open</source>
        <translation>需要打开的文件或文件夹</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="140"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[文件1，文件2...]</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="174"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="174"/>
        <source>Peony-Qt can not get the system&apos;s icon theme. There are 2 reasons might lead to this problem:

1. Peony-Qt might be running as root, that means you have the higher permission and can do some things which normally forbidden. But, you should learn that if you were in a root, the virtual file system will lose some featrue such as you can not use &quot;My Computer&quot;, the theme and icons might also went wrong. So, run peony-qt in a root is not recommended.

2. You are using a non-qt theme for your system but you didn&apos;t install the platform theme plugin for qt&apos;s applications. If you are using gtk-theme, try installing the qt5-gtk2-platformtheme package to resolve this problem.</source>
        <translation>文件管理器无法获取系统图标主题，可能的原因是：

1.正在以管理员用户运行文件管理器，虽然这意味着你拥有更高的权限，但是你必须了解你同时也失去了一些在普通用户下才能够拥有的特征，例如“我的电脑”以及系统主题。如果不是特殊情况，请不要使用管理员用户打开文件管理器。

2.你使用的系统主题不是qt默认支持的主题，并且你没有安装相关的平台插件。如果你正在使用Gtk主题作为系统主题，尝试安装qt5-gtk2-platformtheme以解决此问题。</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="579"/>
        <source>Peony Qt</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.cpp" line="580"/>
        <source>Author:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

Copyright (C): 2020, KylinSoft Co., Ltd.</source>
        <translation>作者:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

版权所有(C): 2020, 麒麟软件有限公司.</translation>
    </message>
    <message>
        <source>Author:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

Copyright (C): 2019-2020, KYLIN Software Co., Ltd.</source>
        <translation type="vanished">作者:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

版权所有(C): 2019-2020,麒麟软件有限公司.</translation>
    </message>
    <message>
        <source>Author: 
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

Copyright (C): 2019-2020, KYLIN Software Co., Ltd.</source>
        <translation type="vanished">作者:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

版权所有(C): 2019-2020,麒麟软件有限公司.</translation>
    </message>
    <message>
        <source>Authour: 
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

Copyright (C): 2019-2020, KYLIN Software Co., Ltd.</source>
        <translation type="vanished">作者:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

版权所有(C): 2019-2020,麒麟软件有限公司.</translation>
    </message>
    <message>
        <source>Authour: 
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

Copyright (C): 2019-2020, Tianjin KYLIN Information Technology Co., Ltd.</source>
        <translation type="vanished">作者:
	Yue Lan &lt;lanyue@kylinos.cn&gt;
	Meihong He &lt;hemeihong@kylinos.cn&gt;

版权所有(C): 2019-2020,天津麒麟信息技术有限公司.</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.h" line="60"/>
        <source>Close all peony-qt windows and quit</source>
        <translation>关闭所有窗口并退出</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.h" line="61"/>
        <source>Show items</source>
        <translation>打开文件所在目录并选中它们</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.h" line="62"/>
        <source>Show folders</source>
        <translation>显示文件夹下的内容</translation>
    </message>
    <message>
        <location filename="../../src/peony-application.h" line="63"/>
        <source>Show properties</source>
        <translation>打开文件属性窗口</translation>
    </message>
</context>
<context>
    <name>SortTypeMenu</name>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="33"/>
        <source>File Name</source>
        <translation>文件名称</translation>
    </message>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="45"/>
        <source>File Size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="41"/>
        <source>File Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="37"/>
        <source>Modified Date</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Modified Data</source>
        <translation type="vanished">修改日期</translation>
    </message>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="60"/>
        <source>Ascending</source>
        <translation>升序</translation>
    </message>
    <message>
        <location filename="../../src/control/sort-type-menu.cpp" line="64"/>
        <source>Descending</source>
        <translation>降序</translation>
    </message>
</context>
<context>
    <name>TabStatusBar</name>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="119"/>
        <location filename="../../src/control/tab-status-bar.cpp" line="127"/>
        <source>; %1 folders</source>
        <translation>; %1 个文件夹</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="121"/>
        <location filename="../../src/control/tab-status-bar.cpp" line="129"/>
        <source>; %1 files, %2 total</source>
        <translation>; %1 个文件, 共%2</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="123"/>
        <source>; %1 folder</source>
        <translation>; %1 个文件夹</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="125"/>
        <source>; %1 file, %2</source>
        <translation>; %1 个文件, %2</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="134"/>
        <source>%1 selected</source>
        <translation>选中%1个</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-status-bar.cpp" line="146"/>
        <source>Search &quot;%1&quot; in &quot;%2&quot;</source>
        <translation>在%2中搜索%1</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="155"/>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="159"/>
        <source>Clear</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="163"/>
        <source>Recover</source>
        <translation>还原</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="241"/>
        <source>Close advance search.</source>
        <translation>关闭高级搜索。</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="249"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="258"/>
        <source>Choose other path to search.</source>
        <translation>选择其他搜索路径。</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="267"/>
        <source>Search recursively</source>
        <translation>递归搜索</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="276"/>
        <source>more options</source>
        <translation>更多选项</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="280"/>
        <source>Show/hide advance search</source>
        <translation>显示/隐藏高级搜索</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="340"/>
        <source>Select path</source>
        <translation>选择路径</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="375"/>
        <location filename="../../src/control/tab-widget.cpp" line="459"/>
        <source>is</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="393"/>
        <source>Please input key words...</source>
        <translation>请输入关键词...</translation>
    </message>
    <message>
        <source>Please input kay words...</source>
        <translation type="vanished">请输入关键词...</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.cpp" line="428"/>
        <location filename="../../src/control/tab-widget.cpp" line="446"/>
        <source>contains</source>
        <translation>包含</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="257"/>
        <source>name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="257"/>
        <source>type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="257"/>
        <source>modify time</source>
        <translation>修改时间</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="257"/>
        <source>file size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="258"/>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>all</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="258"/>
        <source>file folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="258"/>
        <source>image</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="258"/>
        <source>video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="259"/>
        <source>text file</source>
        <translation>文本文档</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="259"/>
        <source>audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="259"/>
        <source>others</source>
        <translation>其他</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="259"/>
        <source>wps file</source>
        <translation>WPS文件</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <source>today</source>
        <translation>今天</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <source>this week</source>
        <translation>本周</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <source>this month</source>
        <translation>本月</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <source>this year</source>
        <translation>今年</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="260"/>
        <source>year ago</source>
        <translation>一年前</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>tiny(0-16K)</source>
        <translation>极小</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>small(16k-1M)</source>
        <translation>很小</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>medium(1M-100M)</source>
        <translation>中等</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>big(100M-1G)</source>
        <translation>很大</translation>
    </message>
    <message>
        <location filename="../../src/control/tab-widget.h" line="261"/>
        <source>large(&gt;1G)</source>
        <translation>极大</translation>
    </message>
</context>
</TS>
